/*  VER 009  TAB P   $Id: stat.h,v 1.4.2.1 2003/01/21 20:19:45 egil Exp $
 *
 *  for fstat(), with the usual set of version dependencies
 *
 *  copyright 1996, 1997 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: stat.h,v $
 *  Revision 1.4.2.1  2003/01/21 20:19:45  egil
 *  mktemp() replaced by newstemp()
 *
 *  Revision 1.4  1998/09/09 07:32:14  src
 *  Version 1.1
 *
 *  Revision 1.3  1998/07/12 09:39:30  src
 *  newsx version 1.0
 */

#if HAVE_SYS_STAT_H
#  include <sys/stat.h>
#endif

#ifndef S_ISREG
#  ifdef S_IFMT
#    define S_ISREG(m) (((m) & S_IFMT) == S_IFREG) 
#    define S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
#  else
#    define S_ISREG(m) (((m) & 0170000) == S_0100000)
#    define S_ISDIR(m) (((m) & 0170000) == S_0040000)
#  endif
#endif
